@@ -1,5 +1,6 @@
 /*
  *   SPDX-FileCopyrightText: 2012-2016 Ivan Cukic <ivan.cukic@kde.org>
+ *   SPDX-FileCopyrightText: 2022 Harald Sitter <sitter@kde.org>
  *
  *   SPDX-License-Identifier: GPL-2.0-only OR GPL-3.0-only OR LicenseRef-KDE-Accepted-GPL
  */
@@ -7,11 +8,13 @@
 #ifndef KIO_ACTIVITIES_H
 #define KIO_ACTIVITIES_H
 
-#include <KIO/ForwardingSlaveBase>
-
+#include <KIO/ForwardingWorkerBase>
+#include <KActivities/Consumer>
 #include <utils/d_ptr.h>
 
-class ActivitiesProtocol : public KIO::ForwardingSlaveBase {
+class ActivitiesProtocolApi;
+
+class ActivitiesProtocol : public KIO::ForwardingWorkerBase {
     Q_OBJECT
 
 public:
@@ -20,14 +23,12 @@ public:
 
 protected:
     bool rewriteUrl(const QUrl &url, QUrl &newUrl) override;
-    void listDir(const QUrl &url) override;
-    void prepareUDSEntry(KIO::UDSEntry &entry, bool listing = false) const override;
-    void stat(const QUrl& url) override;
-    void mimetype(const QUrl& url) override;
-    void del(const QUrl& url, bool isfile) override;
+    KIO::WorkerResult listDir(const QUrl &url) override;
+    KIO::WorkerResult stat(const QUrl& url) override;
+    KIO::WorkerResult mimetype(const QUrl& url) override;
 
 private:
-    D_PTR;
+    D_PTRC(ActivitiesProtocolApi);
 };
 
 #endif // KIO_ACTIVITIES_H
