@@ -62,7 +62,7 @@ SMBContext::SMBContext(SMBAuthenticator *authenticator)
     // TODO: refactor; checkPassword should query this on
     // demand to not run into situations where we may have cached
     // the workgroup early on and it changed since. Needs context
-    // being held in the slave though, which opens us up to nullptr
+    // being held in the worker though, which opens us up to nullptr
     // problems should checkPassword be called without init first.
     authenticator->setDefaultWorkgroup(smbc_getWorkgroup(*this));
 
@@ -85,7 +85,7 @@ void SMBContext::auth_cb(SMBCCTX *context, const char *server, const char *share
 #else
         auto *that = static_cast<SMBCContext *>(smbc_option_get(context, "user_data"));
 #endif
-        that->m_authenticator->auth(server, share,
+        that->m_authenticator->auth(context, server, share,
                                     workgroup,wgmaxlen,
                                     username, unmaxlen,
                                     password, pwmaxlen);
